<?php
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * @since Reef 0.1
 */
require get_parent_theme_file_path( 'inc/starter-content.php' );
function reef_setup() {

	/*
 	 * Make theme available for translation.
 	*/
	load_theme_textdomain( 'reef' );

	# Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/**
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	# Set the default content width.
	$GLOBALS['content_width'] = apply_filters( 'reef_content_width', 1050 );

	# Register menu locations.
	register_nav_menus( array(
		'primary'          => esc_html__( 'Primary Menu', 'reef' ),
		'social'           => esc_html__( 'Social Links Menu', 'reef' ),
		'alternative_menu' => esc_html__( 'Alternative Menu', 'reef' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'search-form',
		'caption',
	) );

	# Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'reef_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	# Enable support for selective refresh of widgets in Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );

	# Enable support for custom logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 265,
		'height'      => 75,
		'flex-height' => true,
		'flex-width'  => true,
	) );
	/*
	 * Enable support for Post Formats.
	 *
	 * See: https://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'status',
		'audio',
		'chat',
	) );

	add_theme_support( 'infinite-scroll', array(
	    'container' 	 => 'main',
	    'footer_widgets' => true,
	    'render'         => 'reef_infinite_scroll_render',
	) );

	add_theme_support( 'woocommerce' );

	add_image_size( 'reef-banner', 1142, 500, true );
	add_image_size( 'reef-highlight', 400, 380, true );
	add_image_size( 'reef-full-widget', 750, 380, true );
	add_image_size( 'reef-single-widget', 358, 222, true );
	add_image_size( 'reef-about-widget-lg', 338, 200, true );
	add_image_size( 'reef-about-widget-sm', 76, 76, true );
	add_image_size( 'reef-recent-post', 100, 100, true );
	add_image_size( 'reef-testimonial-thumb', 70, 70, true );
	add_image_size( 'reef-related-post', 210, 230, true );
}
add_action( 'after_setup_theme', 'reef_setup' );

if( ! function_exists( 'reef_infinite_scroll_render' ) ):
/**
 * Set the code to be rendered on for calling posts,
 * hooked to template parts when possible.
 *
 * Note: must define a loop.
 */
function reef_infinite_scroll_render() {
	while ( have_posts() ) : the_post();
		get_template_part( 'template-parts/post/content', get_post_format() );
	endwhile; 
}
endif;
